==> bee-ui-0.0.35.tgz: package/src/Calender/CalenderContent/Day.js <==
import React, {
  PropTypes,
  Component,
} from 'react';
import {
  View,
  Text,
  TouchableOpacity,
} from 'react-native';
import Label from '../../Label';
import styles from './style';

class Day extends Component {
  static propTypes = {
    title: PropTypes.string,
    label: PropTypes.shape({}),
    style: PropTypes.shape({
      dayContainer: View.propTypes.style,
    }),
    isToday: PropTypes.bool,
    onPress: PropTypes.func,
    isSelected: PropTypes.bool,
    isMonthStart: PropTypes.bool,
    disabled: PropTypes.bool,
  }
  static defaultProps = {
    title: null,
    label: null,
    style: {},
    isToday: false,
    onPress: null,
    isSelected: false,
    isMonthStart: false,
    disabled: false,
  }
  isMonth = () => {
    const { isMonthStart, isSelected, isToday, disabled, style } = this.props;
    const currentDay = isToday || isSelected ?
      [styles.selectText, style.selectText] : [styles.defaultDay, style.defaultDay];
    const monthDay = isMonthStart && isSelected ?
      [styles.selectText, style.selectText] : [styles.isMonthStart, style.isMonthStart];
    const disabledDay = disabled ? null : [styles.disabled, style.disabled];
    return isMonthStart ? [currentDay, monthDay, disabledDay] : [currentDay, disabledDay];
  }
  render() {
    const {
      title,
      label,
      style,
      isToday,
      onPress,
      isSelected,
      disabled,
    } = this.props;
    const active = isToday ? [styles.isToday, style.isToday] : null;
    const selectDay = isSelected ? [styles.isSelect, style.isSelect] : null;
    return (
      <View>
        {disabled ?
          (<TouchableOpacity onPress={onPress}>
            <View style={[styles.dayContainer, style.dayContainer]}>
              <View style={[selectDay, active]}>
                <Text style={this.isMonth()}>{title}</Text>
              </View>
            </View>
          </TouchableOpacity>) :
          (<View>
            <View style={[styles.dayContainer, style.dayContainer]}>
              <View style={[selectDay, active]}>
                <Text style={this.isMonth()}>{title}</Text>
              </View>
            </View>
          </View>)
        }
        <View style={styles.label}>
          { label && <Label label={label} />}
        </View>
      </View>
    );
  }
}

export default Day;

==> bee-ui-0.0.40.tgz: package/src/Calender/CalenderContent/Day.js <==
import React, {
  PropTypes,
  Component,
} from 'react';
import {
  View,
  Text,
  TouchableOpacity,
} from 'react-native';
import Label from '../../Label';
import styles from './style';

class Day extends Component {
  static propTypes = {
    title: PropTypes.string,
    label: PropTypes.shape({}),
    style: PropTypes.shape({
      dayContainer: View.propTypes.style,
    }),
    isToday: PropTypes.bool,
    onPress: PropTypes.func,
    isSelected: PropTypes.bool,
    isMonthStart: PropTypes.bool,
    disabled: PropTypes.bool,
  }
  static defaultProps = {
    title: null,
    label: null,
    style: {},
    isToday: false,
    onPress: null,
    isSelected: false,
    isMonthStart: false,
    disabled: false,
  }
  isMonth = () => {
    const { isMonthStart, isSelected, isToday, disabled, style } = this.props;
    const currentDay = isToday || isSelected ?
      [styles.selectText, style.selectText] : [styles.defaultDay, style.defaultDay];
    const monthDay = isMonthStart && isSelected ?
      [styles.selectText, style.selectText] : [styles.isMonthStart, style.isMonthStart];
    const disabledDay = disabled ? null : [styles.disabled, style.disabled];
    return isMonthStart ? [currentDay, monthDay, disabledDay] : [currentDay, disabledDay];
  }
  render() {
    const {
      title,
      label,
      style,
      isToday,
      onPress,
      isSelected,
      disabled,
    } = this.props;
    const active = isToday ? [styles.isToday, style.isToday]
      : [styles.defaultTextBg, style.defaultTextBg];
    const selectDay = isSelected ? [styles.isSelect, style.isSelect] : null;

    return (
      <View>
        {disabled ?
          (<TouchableOpacity onPress={onPress}>
            <View style={[styles.dayContainer, style.dayContainer]}>
              <View style={[selectDay, active]}>
                <Text style={this.isMonth()}>{title}</Text>
              </View>
            </View>
          </TouchableOpacity>) :
          (<View>
            <View style={[styles.dayContainer, style.dayContainer]}>
              <View style={[selectDay, active]}>
                <Text style={this.isMonth()}>{title}</Text>
              </View>
            </View>
          </View>)
        }
        <View style={styles.label}>
          { label && <Label label={label} />}
        </View>
      </View>
    );
  }
}

export default Day;
